==> opensubdiv-3.6.0-1-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/all_e.js <==
var searchData=
[
  ['parameterization_0',['Parameterization',['../a00921.html',1,'Parameterization'],['../a00921.html#a301ad64c8ae0a3ba3af84377138a069f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Parameterization::Parameterization(Sdc::SchemeType scheme, int faceSize)'],['../a00921.html#aa7e0b89d67d34c1dd7a37cdce95f9e2c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Parameterization::Parameterization()'],['../a00921.html#a64a4b29d36851a8d83be05af5b25f886',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Parameterization::Parameterization(Parameterization const &amp;)=default']]],
  ['parameterization_2eh_1',['parameterization.h',['../a00794.html',1,'']]],
  ['patcharray_2',['PatchArray',['../a01325.html',1,'PatchArray'],['../a01325.html#a9c551db8af15f4a0ddf4c2a13ce2505e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchArray::PatchArray(Far::PatchDescriptor desc_in, int numPatches_in, int indexBase_in, int primitiveIdBase_in)'],['../a01325.html#ad9821423935395f540ff8d37d907600a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchArray::PatchArray(Far::PatchDescriptor regDesc_in, Far::PatchDescriptor irregDesc_in, int numPatches_in, int indexBase_in, int primitiveIdBase_in)']]],
  ['patcharrayvector_3',['PatchArrayVector',['../a00912.html#a98098cd229f60d2397d84a76fe654a31',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd']]],
  ['patchbuilder_4',['PatchBuilder',['../a01121.html#a97612a1a955f8b65e6d7e7761ed1cef7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner']]],
  ['patchcoord_5',['PatchCoord',['../a01321.html',1,'PatchCoord'],['../a01321.html#abe64006c4fe55b720f483bd7711bf216',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchCoord::PatchCoord(Far::PatchTable::PatchHandle handleArg, float sArg, float tArg)'],['../a01321.html#a5e6a814c3f060dc9575af4082f4d905e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchCoord::PatchCoord()']]],
  ['patchdescriptor_6',['PatchDescriptor',['../a00973.html',1,'PatchDescriptor'],['../a00973.html#af3f91a4a134cb2e5786990ec81f30d17',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::PatchDescriptor()'],['../a00973.html#a8e33c50700963e8dc99a5f598a32aaa3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::PatchDescriptor(int type)'],['../a00973.html#a6c6de8b1c8212039f4702f70bb75cf02',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::PatchDescriptor(PatchDescriptor const &amp;d)']]],
  ['patchdescriptor_2eh_7',['patchDescriptor.h',['../a00830.html',1,'']]],
  ['patchfacetag_8',['PatchFaceTag',['../a01025.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTableFactory']]],
  ['patchhandle_9',['PatchHandle',['../a00997.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable']]],
  ['patchindex_10',['patchIndex',['../a00997.html#a31bdf15525ab73560c2b725ff7f8ae3a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle']]],
  ['patchmap_11',['PatchMap',['../a00977.html',1,'PatchMap'],['../a00997.html#aff380d8d7f072959898c0a4e25150d2a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle::PatchMap'],['../a00977.html#a016619de52fd79dbcdb879cc12b79200',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchMap::PatchMap()']]],
  ['patchmap_2eh_12',['patchMap.h',['../a00827.html',1,'']]],
  ['patchparam_13',['PatchParam',['../a00989.html',1,'PatchParam'],['../a01329.html',1,'PatchParam']]],
  ['patchparam_2eh_14',['patchParam.h',['../a00836.html',1,'']]],
  ['patchparamarray_15',['PatchParamArray',['../a00908.html#abe07210a029a01571c54276ae28b4d88',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['patchparamtable_16',['PatchParamTable',['../a00908.html#a46ea68db89cc3d55c4191ef7648281ce',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['patchparamvector_17',['PatchParamVector',['../a00912.html#a1e22001c627b0364d6c6d62a3ed05fee',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd']]],
  ['patchprecisiondouble_18',['patchPrecisionDouble',['../a01021.html#a91ce5fe0ce9b9ec6c5afcfb6e1ccaa40',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTableFactory::Options']]],
  ['patchtable_19',['PatchTable',['../a00993.html',1,'PatchTable'],['../a01269.html#adf9352136d44e5999629c6b4530bf4e0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface::PatchTable'],['../a01281.html#adf9352136d44e5999629c6b4530bf4e0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh::PatchTable'],['../a00997.html#ad4867d502f9704b7e45a7974e8918dc3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle::PatchTable'],['../a00993.html#a3419c5d57330d6787f8c14a7677b8d9b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchTable(PatchTable const &amp;src)'],['../a00993.html#a37e24b0244219eef61cc1ab2a5a5450e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchTable(int maxvalence)']]],
  ['patchtable_2eh_20',['patchTable.h',['../a00851.html',1,'']]],
  ['patchtablebuilder_21',['PatchTableBuilder',['../a00993.html#ad452cef79832abb71eef0c3d88acc1a0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchTableBuilder'],['../a01121.html#ad452cef79832abb71eef0c3d88acc1a0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner::PatchTableBuilder']]],
  ['patchtablefactory_22',['PatchTableFactory',['../a01017.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['patchtablefactory_2eh_23',['patchTableFactory.h',['../a00821.html',1,'']]],
  ['patchtagvector_24',['PatchTagVector',['../a01017.html#a37218ea13f75caee4c93cc4e94d26060',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTableFactory']]],
  ['patchvertstable_25',['PatchVertsTable',['../a00993.html#a9484ab8a323750c2f639ee8709b1349b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable']]],
  ['pointdescriptor_26',['PointDescriptor',['../a00937.html',1,'Surface&lt; REAL &gt;::PointDescriptor'],['../a00937.html#ac60ab7fa3966237e2de95cc60defa4de',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface::PointDescriptor::PointDescriptor()'],['../a00937.html#a69d66788e741236b1176159a1d609189',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface::PointDescriptor::PointDescriptor(int n)'],['../a00937.html#a6e6069bdfef867e798fe863f40f4274a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface::PointDescriptor::PointDescriptor(int n, int m)']]],
  ['points_27',['POINTS',['../a00973.html#a1d1cfd8ffb84e947f82999c682b666a7adc0f401e772f1affa81071e70631abbf',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor']]],
  ['populatebaselevel_28',['populateBaseLevel',['../a01117.html#a2c34b14ad2b2ea6959f262de4974fdae',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['populatebaselocalindices_29',['populateBaseLocalIndices',['../a01117.html#a363ef6e3c1fa9e4a58ff0a3852deec66',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['populatefacevertexdescriptor_30',['populateFaceVertexDescriptor',['../a00957.html#a6f2eece993bb137b995618881c7f9160',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::SurfaceFactoryMeshAdapter']]],
  ['preparecomponenttagsandsharpness_31',['prepareComponentTagsAndSharpness',['../a01133.html#a8d7f178267895f2a90585e60849b9119',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparecomponenttopologyassignment_32',['prepareComponentTopologyAssignment',['../a01133.html#a30ee63853ace8ecb0c3c2a6e3303aefc',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparecomponenttopologysizing_33',['prepareComponentTopologySizing',['../a01133.html#aba57674bcc5cb7367ce1fe527ec219ad',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparefacevaryingchannels_34',['prepareFaceVaryingChannels',['../a01133.html#ac800e6db9b484b31f8fa11799ee4ac1b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparepatchpoints_35',['PreparePatchPoints',['../a00933.html#ac11caa08d0e7f7ce63e6f3292b20840a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface']]],
  ['preservequads_36',['PreserveQuads',['../a00965.html#a98820ec764e776bd556a9b80b872b78f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Tessellation::Options::PreserveQuads(bool on)'],['../a00965.html#ae2ec197b850e8bd12878cc67a503a07a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Tessellation::Options::PreserveQuads() const']]],
  ['primitiveidbase_37',['primitiveIdBase',['../a01325.html#a5a054ce6862ecc6ea8c404fadb1c9a15',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchArray']]],
  ['primvarrefiner_38',['PrimvarRefiner',['../a01037.html',1,'PrimvarRefiner'],['../a01037.html#a643d81a2ae20ba1897433f5af5a3697a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefiner::PrimvarRefiner()']]],
  ['primvarrefiner_2eh_39',['primvarRefiner.h',['../a00842.html',1,'']]],
  ['primvarrefinerreal_40',['PrimvarRefinerReal',['../a01029.html',1,'PrimvarRefinerReal&lt; REAL &gt;'],['../a01121.html#a2cb48b58c1c2ecef25abb39339a95ac1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner::PrimvarRefinerReal'],['../a01029.html#a1fe1fbda93c01c326f13929d1c3c6247',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal::PrimvarRefinerReal()']]],
  ['primvarrefinerreal_3c_20float_20_3e_41',['PrimvarRefinerReal&lt; float &gt;',['../a01029.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['print_42',['print',['../a00973.html#acd0f82d3c49b8a5dd436d4003c44b713',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::print()'],['../a00993.html#acd0f82d3c49b8a5dd436d4003c44b713',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::print()']]],
  ['printtopology_43',['PrintTopology',['../a01113.html#a3f963f5352658762e7a2e8d82fb888a0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyLevel']]],
  ['ptexidx_44',['ptexIdx',['../a01093.html#afb60a8380cb9df186de7183b32bd84e2',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableFactoryReal::LocationArray']]],
  ['ptexindices_45',['PtexIndices',['../a01041.html',1,'PtexIndices'],['../a01121.html#a3e6c896f40ac50aec4b28f19bc4eae9c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner::PtexIndices'],['../a01041.html#a7b5dd5f4c76d684d924adf477eeea0a3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PtexIndices::PtexIndices()']]],
  ['ptexindices_2eh_46',['ptexIndices.h',['../a00860.html',1,'']]]
];

==> opensubdiv-3.6.0-2-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/all_e.js <==
var searchData=
[
  ['parameterization_0',['Parameterization',['../a00921.html',1,'Parameterization'],['../a00921.html#a301ad64c8ae0a3ba3af84377138a069f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Parameterization::Parameterization(Sdc::SchemeType scheme, int faceSize)'],['../a00921.html#aa7e0b89d67d34c1dd7a37cdce95f9e2c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Parameterization::Parameterization()'],['../a00921.html#a64a4b29d36851a8d83be05af5b25f886',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Parameterization::Parameterization(Parameterization const &amp;)=default']]],
  ['parameterization_2eh_1',['parameterization.h',['../a00824.html',1,'']]],
  ['patcharray_2',['PatchArray',['../a01325.html',1,'PatchArray'],['../a01325.html#a9c551db8af15f4a0ddf4c2a13ce2505e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchArray::PatchArray(Far::PatchDescriptor desc_in, int numPatches_in, int indexBase_in, int primitiveIdBase_in)'],['../a01325.html#ad9821423935395f540ff8d37d907600a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchArray::PatchArray(Far::PatchDescriptor regDesc_in, Far::PatchDescriptor irregDesc_in, int numPatches_in, int indexBase_in, int primitiveIdBase_in)']]],
  ['patcharrayvector_3',['PatchArrayVector',['../a00912.html#a98098cd229f60d2397d84a76fe654a31',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd']]],
  ['patchbuilder_4',['PatchBuilder',['../a01121.html#a97612a1a955f8b65e6d7e7761ed1cef7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner']]],
  ['patchcoord_5',['PatchCoord',['../a01321.html',1,'PatchCoord'],['../a01321.html#abe64006c4fe55b720f483bd7711bf216',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchCoord::PatchCoord(Far::PatchTable::PatchHandle handleArg, float sArg, float tArg)'],['../a01321.html#a5e6a814c3f060dc9575af4082f4d905e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchCoord::PatchCoord()']]],
  ['patchdescriptor_6',['PatchDescriptor',['../a00973.html',1,'PatchDescriptor'],['../a00973.html#af3f91a4a134cb2e5786990ec81f30d17',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::PatchDescriptor()'],['../a00973.html#a8e33c50700963e8dc99a5f598a32aaa3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::PatchDescriptor(int type)'],['../a00973.html#a6c6de8b1c8212039f4702f70bb75cf02',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::PatchDescriptor(PatchDescriptor const &amp;d)']]],
  ['patchdescriptor_2eh_7',['patchDescriptor.h',['../a00869.html',1,'']]],
  ['patchfacetag_8',['PatchFaceTag',['../a01025.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTableFactory']]],
  ['patchhandle_9',['PatchHandle',['../a00997.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable']]],
  ['patchindex_10',['patchIndex',['../a00997.html#a31bdf15525ab73560c2b725ff7f8ae3a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle']]],
  ['patchmap_11',['PatchMap',['../a00977.html',1,'PatchMap'],['../a00997.html#aff380d8d7f072959898c0a4e25150d2a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle::PatchMap()'],['../a00977.html#a016619de52fd79dbcdb879cc12b79200',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchMap::PatchMap()']]],
  ['patchmap_2eh_12',['patchMap.h',['../a00881.html',1,'']]],
  ['patchparam_13',['PatchParam',['../a00989.html',1,'PatchParam'],['../a01329.html',1,'PatchParam']]],
  ['patchparam_2eh_14',['patchParam.h',['../a00872.html',1,'']]],
  ['patchparamarray_15',['PatchParamArray',['../a00908.html#abe07210a029a01571c54276ae28b4d88',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['patchparamtable_16',['PatchParamTable',['../a00908.html#a46ea68db89cc3d55c4191ef7648281ce',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['patchparamvector_17',['PatchParamVector',['../a00912.html#a1e22001c627b0364d6c6d62a3ed05fee',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd']]],
  ['patchprecisiondouble_18',['patchPrecisionDouble',['../a01021.html#a91ce5fe0ce9b9ec6c5afcfb6e1ccaa40',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTableFactory::Options']]],
  ['patchtable_19',['PatchTable',['../a00993.html',1,'PatchTable'],['../a01269.html#adf9352136d44e5999629c6b4530bf4e0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface::PatchTable'],['../a01281.html#adf9352136d44e5999629c6b4530bf4e0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh::PatchTable'],['../a00997.html#ad4867d502f9704b7e45a7974e8918dc3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle::PatchTable()'],['../a00993.html#a3419c5d57330d6787f8c14a7677b8d9b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchTable(PatchTable const &amp;src)'],['../a00993.html#a37e24b0244219eef61cc1ab2a5a5450e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchTable(int maxvalence)']]],
  ['patchtable_2eh_20',['patchTable.h',['../a00845.html',1,'']]],
  ['patchtablebuilder_21',['PatchTableBuilder',['../a00993.html#ad452cef79832abb71eef0c3d88acc1a0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchTableBuilder()'],['../a01121.html#ad452cef79832abb71eef0c3d88acc1a0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner::PatchTableBuilder()']]],
  ['patchtablefactory_22',['PatchTableFactory',['../a01017.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['patchtablefactory_2eh_23',['patchTableFactory.h',['../a00851.html',1,'']]],
  ['patchtagvector_24',['PatchTagVector',['../a01017.html#a37218ea13f75caee4c93cc4e94d26060',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTableFactory']]],
  ['patchvertstable_25',['PatchVertsTable',['../a00993.html#a9484ab8a323750c2f639ee8709b1349b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable']]],
  ['pointdescriptor_26',['PointDescriptor',['../a00937.html',1,'Surface&lt; REAL &gt;::PointDescriptor'],['../a00937.html#ac60ab7fa3966237e2de95cc60defa4de',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface::PointDescriptor::PointDescriptor()'],['../a00937.html#a69d66788e741236b1176159a1d609189',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface::PointDescriptor::PointDescriptor(int n)'],['../a00937.html#a6e6069bdfef867e798fe863f40f4274a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface::PointDescriptor::PointDescriptor(int n, int m)']]],
  ['points_27',['POINTS',['../a00973.html#a1d1cfd8ffb84e947f82999c682b666a7adc0f401e772f1affa81071e70631abbf',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor']]],
  ['populatebaselevel_28',['populateBaseLevel',['../a01117.html#a2c34b14ad2b2ea6959f262de4974fdae',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['populatebaselocalindices_29',['populateBaseLocalIndices',['../a01117.html#a363ef6e3c1fa9e4a58ff0a3852deec66',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['populatefacevertexdescriptor_30',['populateFaceVertexDescriptor',['../a00957.html#a6f2eece993bb137b995618881c7f9160',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::SurfaceFactoryMeshAdapter']]],
  ['preparecomponenttagsandsharpness_31',['prepareComponentTagsAndSharpness',['../a01133.html#a8d7f178267895f2a90585e60849b9119',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparecomponenttopologyassignment_32',['prepareComponentTopologyAssignment',['../a01133.html#a30ee63853ace8ecb0c3c2a6e3303aefc',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparecomponenttopologysizing_33',['prepareComponentTopologySizing',['../a01133.html#aba57674bcc5cb7367ce1fe527ec219ad',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparefacevaryingchannels_34',['prepareFaceVaryingChannels',['../a01133.html#ac800e6db9b484b31f8fa11799ee4ac1b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactoryBase']]],
  ['preparepatchpoints_35',['PreparePatchPoints',['../a00933.html#ac11caa08d0e7f7ce63e6f3292b20840a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Surface']]],
  ['preservequads_36',['PreserveQuads',['../a00965.html#a98820ec764e776bd556a9b80b872b78f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Tessellation::Options::PreserveQuads(bool on)'],['../a00965.html#ae2ec197b850e8bd12878cc67a503a07a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::Tessellation::Options::PreserveQuads() const']]],
  ['primitiveidbase_37',['primitiveIdBase',['../a01325.html#a5a054ce6862ecc6ea8c404fadb1c9a15',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::PatchArray']]],
  ['primvarrefiner_38',['PrimvarRefiner',['../a01037.html',1,'PrimvarRefiner'],['../a01037.html#a643d81a2ae20ba1897433f5af5a3697a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefiner::PrimvarRefiner()']]],
  ['primvarrefiner_2eh_39',['primvarRefiner.h',['../a00860.html',1,'']]],
  ['primvarrefinerreal_40',['PrimvarRefinerReal',['../a01029.html',1,'PrimvarRefinerReal&lt; REAL &gt;'],['../a01121.html#a2cb48b58c1c2ecef25abb39339a95ac1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner::PrimvarRefinerReal()'],['../a01029.html#a1fe1fbda93c01c326f13929d1c3c6247',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal::PrimvarRefinerReal()']]],
  ['primvarrefinerreal_3c_20float_20_3e_41',['PrimvarRefinerReal&lt; float &gt;',['../a01029.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['print_42',['print',['../a00973.html#acd0f82d3c49b8a5dd436d4003c44b713',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor::print()'],['../a00993.html#acd0f82d3c49b8a5dd436d4003c44b713',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::print()']]],
  ['printtopology_43',['PrintTopology',['../a01113.html#a3f963f5352658762e7a2e8d82fb888a0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyLevel']]],
  ['ptexidx_44',['ptexIdx',['../a01093.html#afb60a8380cb9df186de7183b32bd84e2',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableFactoryReal::LocationArray']]],
  ['ptexindices_45',['PtexIndices',['../a01041.html',1,'PtexIndices'],['../a01121.html#a3e6c896f40ac50aec4b28f19bc4eae9c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner::PtexIndices()'],['../a01041.html#a7b5dd5f4c76d684d924adf477eeea0a3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PtexIndices::PtexIndices()']]],
  ['ptexindices_2eh_46',['ptexIndices.h',['../a00878.html',1,'']]]
];
